BeSnappy HTTP API client
=======================

An unofficial client library for the `BeSnappy`_ HTTP API.

.. _BeSnappy: https://github.com/BeSnappy/api-docs

|gha-ci|_ |gha-cover|_

.. |gha-ci| image:: https://travis-ci.org/westerncapelabs/besnappy.png?branch=develop
.. _gha-ci: https://travis-ci.org/westerncapelabs/besnappy

.. |gha-cover| image:: https://coveralls.io/repos/westerncapelabs/besnappy/badge.png?branch=develop
.. _gha-cover: https://coveralls.io/r/westerncapelabs/besnappy

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.

Note: API coverage is currently extremely low.


